==> lcfm_shapefiles-0.3.1-py3-none-any.whl: lcfm_shapefiles/labels.py <==
import enum

import numpy as np

LCM10_COLORS_MATPLOTLIB = [
    "forestgreen",
    "orange",
    "yellow",
    "violet",
    "red",
    "silver",
    "gray",
    "steelblue",
    "mediumaquamarine",
    "mediumspringgreen",
    "papayawhip",
    "black"
]

class LCM10LabelsColors(enum.Enum):
    TREE = (
        10,
        "tree",
        "tree",
        "Trees covered area",
        np.array([0, 100, 0]) / 255,  # Green
    )
    SHRUB = (
        20,
        "shrub",
        "shrub",
        "Shrub cover area",
        np.array([255, 187, 34]) / 255,  # Orange
    )
    GRASS = (
        30,
        "grass",
        "grassland",
        "Grassland",
        np.array([255, 255, 76]) / 255,  # Yellow
    )
    CROP = (40, "crop", "crops", "Cropland", np.array([240, 150, 255]) / 255)  # Violet
    BUILT = (
        50,
        "built",
        "urban/built-up",
        "Built-up",
        np.array([250, 0, 0]) / 255,  # Red
    )
    BARE = (60, "bare", "bare", "Bare / sparse vegetation", np.array([180, 180, 180]) / 255)  # Silver
    SNOW_AND_ICE = (
        70,
        "snow",
        "snow and ice",
        "Snow and ice",
        np.array([240, 240, 240]) / 255,  # White
    )
    WATER = (
        80,
        "water",
        "water",
        "Permanent water bodies",
        np.array([0, 100, 200]) / 255,  # Steel Blue
    )
    WETLAND = (
        90,
        "wetland",
        "wetland (herbaceous)",
        "Herbaceous wetland",
        np.array([0, 150, 160]) / 255,  # Medium Aquamarine
    )
    LICHENS = (
        100,
        "lichens_mosses",
        "Lichen and moss",
        "Moss and lichen",
        np.array([250, 230, 160]) / 255,  # Papaya Whip
    )
    MANGROVES = (
        110,
        "mangroves",
        None,
        "Mangroves",
        np.array([0, 207, 117]) / 255,  # Medium Spring Green
    )
    UNCLASSIFIABLE = (
        254,
        "unclassifiable",
        "unclassifiable",
        "Unclassifiable",
        np.array([0, 0, 0]) / 255,  # Black
    )
    # TODO: relegate iiasa's "not sure" to "unclassifiable" instead?
    NO_DATA = (255, "nodata", "Not sure", "No Data", np.array([0, 0, 0]))  # Transparent

    def __init__(self, val1, val2, val3, val4, val5):
        self.id = val1
        self.class_name = val2
        self.iiasa_name = val3
        self.product_class_name = val4
        self.color = val5

    @classmethod
    def id_to_class_name_mapping(cls):
        return {item.id: item.class_name for item in cls}

def get_labels_encodings():
    return [
        {
            "id": lc.id,
            "color": lc.color,
            "iiasa_name": lc.iiasa_name,
            "name": lc.class_name,
            "product_name": lc.product_class_name,
        }
        for lc in LCM10LabelsColors
    ]

LCM10_ENCODINGS = get_labels_encodings()
LCM10_ENCODINGS_DICT = {e["id"]: e for e in LCM10_ENCODINGS}

LCM10_LABELS = [e["id"] for e in LCM10_ENCODINGS]
LCM10_COLORMAP = {
    e["id"]: (e["color"] * 255).astype(int).tolist() + [0 if e["name"] == "nodata" else 255] for e in LCM10_ENCODINGS
}
LCM10_LABEL_NAMES = {k: LCM10_ENCODINGS_DICT[k]["name"] for k in LCM10_ENCODINGS_DICT.keys()}

==> lcfm_shapefiles-0.4.11-py3-none-any.whl: lcfm_shapefiles/labels.py <==
import enum

import numpy as np

LCM10_COLORS_MATPLOTLIB = [
    "forestgreen",
    "orange",
    "yellow",
    "violet",
    "red",
    "silver",
    "gray",
    "steelblue",
    "mediumaquamarine",
    "mediumspringgreen",
    "papayawhip",
    "black",
]


class LCM10LabelsColors(enum.Enum):
    TREE = (
        10,
        "tree",
        "tree",
        "Trees covered area",
        np.array([0, 100, 0]) / 255,  # Green
    )
    SHRUB = (
        20,
        "shrub",
        "shrub",
        "Shrub cover area",
        np.array([255, 187, 34]) / 255,  # Orange
    )
    GRASS = (
        30,
        "grass",
        "grassland",
        "Grassland",
        np.array([255, 255, 76]) / 255,  # Yellow
    )
    CROP = (40, "crop", "crops", "Cropland", np.array([240, 150, 255]) / 255)  # Violet
    BUILT = (
        50,
        "built",
        "urban/built-up",
        "Built-up",
        np.array([250, 0, 0]) / 255,  # Red
    )
    BARE = (
        60,
        "bare",
        "bare",
        "Bare / sparse vegetation",
        np.array([180, 180, 180]) / 255,
    )  # Silver
    SNOW_AND_ICE = (
        70,
        "snow",
        "snow and ice",
        "Snow and ice",
        np.array([240, 240, 240]) / 255,  # White
    )
    WATER = (
        80,
        "water",
        "water",
        "Permanent water bodies",
        np.array([0, 100, 200]) / 255,  # Steel Blue
    )
    WETLAND = (
        90,
        "wetland",
        "wetland (herbaceous)",
        "Herbaceous wetland",
        np.array([0, 150, 160]) / 255,  # Medium Aquamarine
    )
    LICHENS = (
        100,
        "lichens_mosses",
        "Lichen and moss",
        "Moss and lichen",
        np.array([250, 230, 160]) / 255,  # Papaya Whip
    )
    MANGROVES = (
        110,
        "mangroves",
        None,
        "Mangroves",
        np.array([0, 207, 117]) / 255,  # Medium Spring Green
    )
    UNCLASSIFIABLE = (
        254,
        "unclassifiable",
        "unclassifiable",
        "Unclassifiable",
        np.array([0, 0, 0]) / 255,  # Black
    )
    # TODO: relegate iiasa's "not sure" to "unclassifiable" instead?
    NO_DATA = (255, "nodata", "Not sure", "No Data", np.array([0, 0, 0]))  # Transparent

    def __init__(self, val1: int, val2: str, val3: str, val4: str, val5: np.array):
        self.id = val1
        self.class_name = val2
        self.iiasa_name = val3
        self.product_class_name = val4
        self.color = val5

    @classmethod
    def id_to_class_name_mapping(cls):
        return {item.id: item.class_name for item in cls}


def get_labels_encodings():
    return [
        {
            "id": lc.id,
            "color": lc.color,
            "iiasa_name": lc.iiasa_name,
            "name": lc.class_name,
            "product_name": lc.product_class_name,
        }
        for lc in LCM10LabelsColors
    ]


LCM10_ENCODINGS = get_labels_encodings()
LCM10_ENCODINGS_DICT = {e["id"]: e for e in LCM10_ENCODINGS}

LCM10_LABELS = [e["id"] for e in LCM10_ENCODINGS]
LCM10_COLORMAP = {
    e["id"]: (e["color"] * 255).astype(int).tolist()
    + [0 if e["name"] == "nodata" else 255]
    for e in LCM10_ENCODINGS
}
LCM10_LABEL_NAMES = {
    k: LCM10_ENCODINGS_DICT[k]["name"] for k in LCM10_ENCODINGS_DICT.keys()
}
